@@ -11,6 +11,8 @@ use Carp qw(croak cluck);
 use POSIX qw(ceil);
 BEGIN { *Dumper = \&AnyEvent::RabbitMQ::Dumper }
 
+our $VERSION = '1.22'; # VERSION
+
 use namespace::clean;
 
 use constant {
@@ -617,12 +619,14 @@ sub get {
     my $self = shift;
     my ($cb, $failure_cb, %args) = $self->_delete_cbs(@_);
 
+    my $no_ack = delete $args{no_ack} // 1;
+
     return $self if !$self->_check_open($failure_cb);
 
     $self->{connection}->_push_write_and_read(
         'Basic::Get',
         {
-            no_ack => 1,
+            no_ack => $no_ack,
             %args, # queue
             ticket => 0,
         },
@@ -1110,7 +1114,24 @@ The routing key to bind with
 
 =head2 declare_queue
 
-Declare a queue, that is, create it if it doesn't exist yet.
+Declare a queue (create it if it doesn't exist yet) for publishing messages
+to on the server.
+
+  my $done    = AnyEvent->condvar;
+  $channel->declare_queue(
+     exchange    => $queue_exchange,
+     queue       => $queueName,
+     durable     => 0,
+     auto_delete => 1,
+     passive     => 0,
+     arguments   => { 'x-expires' => 0, },
+     on_success  => sub { $done->send; },
+     on_failure  => sub {
+         say "Unable to create queue $queueName";
+         $done->send;
+     },
+  );
+  $done->recv;
 
 Arguments:
 
@@ -1161,6 +1182,25 @@ Callback that is called when the declaration of the queue has failed.
 
 default 0
 
+=for comment
+XXX Is "exchange" a valid parameter?
+
+=item arguments
+
+C<arguments> is a hashref of additional parameters which RabbitMQ extensions
+may use. This list is not complete and your RabbitMQ server configuration will
+determine which arguments are valid and how they act.
+
+=over
+
+=item x-expires
+
+The queue will automatically be removed after being idle for this many milliseconds.
+
+Default of 0 disables automatic queue removal.
+
+=back
+
 =back
 
 =head2 bind_queue
@@ -1349,6 +1389,10 @@ a notification that there was nothing to collect from the queue.
 
 This callback will be called if an error is signalled on this channel.
 
+=item no_ack
+
+0 or 1, default 1
+
 =back
 
 =head2 ack
